mod avoid_empty_tables;
mod build;
mod dev;
mod dry_run;
mod gc_keep_used_patch;
mod gc_patch;
mod gc_profile;
mod gc_replace;
mod help;
mod invalid_arg;
mod invalid_dep;
mod invalid_package;
mod invalid_package_multiple;
mod invalid_section;
mod invalid_section_dep;
mod invalid_target;
mod invalid_target_dep;
mod multiple_deps;
mod multiple_dev;
mod no_arg;
mod offline;
mod optional_dep_feature;
mod optional_feature;
mod package;
mod remove_basic;
mod target;
mod target_build;
mod target_dev;
mod update_lock_file;
mod workspace;
mod workspace_non_virtual;
mod workspace_preserved;
